@@ -48,6 +48,13 @@ fi
 rm -rf $wwwdirselect/stats
 cp -rp stats $wwwdirselect
 
+# specific for log filters
+mkdir $wwwdirselect/stats/downloads
+chown www-data:www-data $wwwdirselect/stats/downloads
+ln -s /tmp/logContent $wwwdirselect/stats/logContent
+ln -s /tmp/cacheContent $wwwdirselect/stats/cacheContent
+
+
 echo "Configuring Asterisk-Addons Modules..."
 install -m $perm_files $src/configs/cdr_mysql.conf $dst/etc/asterisk/cdr_mysql.conf
 
@@ -60,7 +67,7 @@ done
 echo -n "Enter apache web root directory[$apachedirselect]: "
 read apachediruser
 if [ -n "$apachediruser" ]; then
-	apachedirselect=$apachediruser
+   apachedirselect=$apachediruser
 fi
 echo "Selected root dir : $apachedirselect"
 if [ -d $apachedirselect ];then
