@@ -1,4 +1,4 @@
-<?
+<?php
 require_once(dirname(__FILE__) . "/lib/defines.php");
 
 //Set $FG_TABLE_COL and $VCHAR_SEARCH 
@@ -309,25 +309,23 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 //-->
 </script>
 
-
-
 <!-- ** ** ** ** ** Part for the research ** ** ** ** ** -->
 	<center>
-	<FORM METHOD=POST ACTION="<?=$PHP_SELF?>?&order=<?=$order?>&sens=<?=$sens?>&current_page=<?=$current_page?>">
+	<FORM METHOD=POST ACTION="<?php echo $PHP_SELF?>?&order=<?php echo $order?>&sens=<?php echo $sens?>&current_page=<?php echo $current_page?>">
 	<INPUT TYPE="hidden" NAME="posted" value=1>
 	<INPUT TYPE="hidden" NAME="current_page" value=0>	
 		<table class="bar-status" width="750" border="0" cellspacing="1" cellpadding="2" align="center">
 			<tbody><tr>
         		<td class="bar-search" align="left" bgcolor="#555577">
 
-					<input type="radio" name="Period" value="Month" <? if (($Period=="Month") || !isset($Period)){ ?>checked="checked" <? } ?>> 
+					<input type="radio" name="Period" value="Month" <?php if (($Period=="Month") || !isset($Period)){ ?>checked="checked" <?php } ?>> 
 					<font face="verdana" size="1" color="#ffffff"><b>MONTH</b></font>
 				</td>
       			<td class="bar-search" align="left" bgcolor="#cddeff">
 					<table width="100%" border="0" cellspacing="0" cellpadding="0" bgcolor="#cddeff"><tr><td>
-	  				<input type="checkbox" name="frommonth" value="true" <? if ($frommonth){ ?>checked<?}?>> 
+	  				<input type="checkbox" name="frommonth" value="true" <?php if ($frommonth){ ?>checked<?php }?>> 
 					From : <select name="fromstatsmonth">
-					<?	$year_actual = date("Y");  	
+					<?php	$year_actual = date("Y");  	
 						for ($i=$year_actual;$i >= $year_actual-1;$i--)
 						{		   
 							   $monthname = array( "January", "February","March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
@@ -345,9 +343,9 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 					?>		
 					</select>
 					</td><td>&nbsp;&nbsp;
-					<input type="checkbox" name="tomonth" value="true" <? if ($tomonth){ ?>checked<?}?>> 
+					<input type="checkbox" name="tomonth" value="true" <?php if ($tomonth){ ?>checked<?php }?>> 
 					To : <select name="tostatsmonth">
-					<?	$year_actual = date("Y");  	
+					<?php	$year_actual = date("Y");  	
 						for ($i=$year_actual;$i >= $year_actual-1;$i--)
 						{		   
 							   $monthname = array( "January", "February","March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
@@ -370,14 +368,14 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 			
 			<tr>
         		<td align="left" bgcolor="#000033">
-					<input type="radio" name="Period" value="Day" <? if ($Period=="Day"){ ?>checked="checked" <? } ?>> 
+					<input type="radio" name="Period" value="Day" <?php if ($Period=="Day"){ ?>checked="checked" <?php } ?>> 
 					<font face="verdana" size="1" color="#ffffff"><b>DAY</b></font>
 				</td>
       			<td align="left" bgcolor="#acbdee">
 					<table width="100%" border="0" cellspacing="0" cellpadding="0" bgcolor="#acbdee"><tr><td>
-	  				<input type="checkbox" name="fromday" value="true" <? if ($fromday){ ?>checked<?}?>> From : 
+	  				<input type="checkbox" name="fromday" value="true" <?php if ($fromday){ ?>checked<?php }?>> From : 
 					<select name="fromstatsday_sday">
-						<? 
+						<?php 
 							for ($i=1;$i<=31;$i++){
 								if ($fromstatsday_sday==sprintf("%02d",$i)){$selected="selected";}else{$selected="";}
 								echo '<option value="'.sprintf("%02d",$i)."\"$selected>".sprintf("%02d",$i).'</option>';
@@ -385,7 +383,7 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 						?>	
 					</select>
 				 	<select name="fromstatsmonth_sday">
-					<?	$year_actual = date("Y");  	
+					<?php	$year_actual = date("Y");  	
 						for ($i=$year_actual;$i >= $year_actual-1;$i--)
 						{		   
 							   $monthname = array( "January", "February","March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
@@ -403,7 +401,7 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 					?>
 					</select>
 					<select name="fromstatshour_sday">
-						<? 
+						<?php 
 							for ($i=0;$i<=23;$i++){
 								if ($fromstatshour_sday==sprintf("%02d",$i)){$selected="selected";}else{$selected="";}
 								echo '<option value="'.sprintf("%02d",$i)."\"$selected>".sprintf("%02dh",$i).'</option>';
@@ -411,9 +409,9 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 						?>	
 					</select>
 					</td><td>&nbsp;&nbsp;
-					<input type="checkbox" name="today" value="true" <? if ($today){ ?>checked<?}?>> To : 
+					<input type="checkbox" name="today" value="true" <?php if ($today){ ?>checked<?php }?>> To : 
 					<select name="tostatsday_sday">
-					<? 
+					<?php 
 						for ($i=1;$i<=31;$i++){
 							if ($tostatsday_sday==sprintf("%02d",$i)){$selected="selected";}else{$selected="";}
 							echo '<option value="'.sprintf("%02d",$i)."\"$selected>".sprintf("%02d",$i).'</option>';
@@ -421,7 +419,7 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 					?>						
 					</select>
 				 	<select name="tostatsmonth_sday">
-					<?	$year_actual = date("Y");  	
+					<?php	$year_actual = date("Y");  	
 						for ($i=$year_actual;$i >= $year_actual-1;$i--)
 						{		   
 							   $monthname = array( "January", "February","March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
@@ -440,7 +438,7 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 					</select>
 					</select>
 					<select name="tostatshour_sday">
-						<? 
+						<?php 
 							for ($i=0;$i<=23;$i++){
 								if ($tostatshour_sday==sprintf("%02d",$i)){$selected="selected";}else{$selected="";}
 								echo '<option value="'.sprintf("%02d",$i)."\"$selected>".sprintf("%02dh",$i).'</option>';
@@ -457,19 +455,19 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 				</td>				
 				<td class="bar-search" align="left" bgcolor="#cddeff">
 				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr>
-				<td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="duration1" size="4" value="<?=$duration1?>"></td>
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="4" <?if($duration1type==4){?>checked<?}?>>&gt;</td>
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="5" <?if($duration1type==5){?>checked<?}?>>&gt; egal</td>
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="1" <?if((!isset($duration1type))||($duration1type==1)){?>checked<?}?>>Egal</td>
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="2" <?if($duration1type==2){?>checked<?}?>>&lt; egal</td>
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="3" <?if($duration1type==3){?>checked<?}?>>&lt;</td>	
+				<td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="duration1" size="4" value="<?php echo $duration1?>"></td>
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="4" <?php if($duration1type==4){?>checked<?php }?>>&gt;</td>
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="5" <?php if($duration1type==5){?>checked<?php }?>>&gt; egal</td>
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="1" <?php if((!isset($duration1type))||($duration1type==1)){?>checked<?php }?>>Egal</td>
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="2" <?php if($duration1type==2){?>checked<?php }?>>&lt; egal</td>
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration1type" value="3" <?php if($duration1type==3){?>checked<?php }?>>&lt;</td>	
 				<td width="5%" class="bar-search" align="center" bgcolor="#cddeff"></td>
 				
-				<td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="duration2" size="4" value="<?=$duration2?>"></td>			
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="4" <?if($duration2type==4){?>checked<?}?>>&gt;</td>
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="5" <?if($duration2type==5){?>checked<?}?>>&gt; egal</td>								
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="2" <?if($duration2type==1){?>checked<?}?>>&lt; egal</td>
-				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="3" <?if($duration2type==3){?>checked<?}?>>&lt;</td>	
+				<td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="duration2" size="4" value="<?php echo $duration2?>"></td>			
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="4" <?php if($duration2type==4){?>checked<?php }?>>&gt;</td>
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="5" <?php if($duration2type==5){?>checked<?php }?>>&gt; egal</td>								
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="2" <?php if($duration2type==1){?>checked<?php }?>>&lt; egal</td>
+				<td class="bar-search" align="center" bgcolor="#cddeff"><input type="radio" NAME="duration2type" value="3" <?php if($duration2type==3){?>checked<?php }?>>&lt;</td>	
 				</tr></table>
 				</td>
 			</tr>
@@ -478,12 +476,12 @@ function MM_openBrWindow(theURL,winName,features) { //v2.0
 					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;CHANNEL</b></font>
 				</td>				
 				<td class="bar-search" align="left" bgcolor="#acbdee">
-				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr><td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="channel" value="<?=$channel?>"></td>				
+				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr><td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="channel" value="<?php echo $channel?>"></td>				
 				</tr></table></td>
 			</tr>
 
 
-<?
+<?php
 
 
 $colors = array ( 1 => array ('555577','cddeff'), 0 => array('000033','acbdee'));
@@ -494,27 +492,27 @@ $cpt++;
 
 ?>
 		<tr>
-				<td class="bar-search" align="left" bgcolor="#<?=$colors[$cpt%2][0]?>">			
-					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?=$description?></b></font>
+				<td class="bar-search" align="left" bgcolor="#<?php echo $colors[$cpt%2][0]?>">			
+					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?php echo $description?></b></font>
 				</td>				
-				<td class="bar-search" align="left" bgcolor="#<?=$colors[$cpt%2][1]?>">
-				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr><td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="<?=$varname?>" value="<?=$$varname?>"></td>
-				<td class="bar-search" align="center" bgcolor="#<?=$colors[$cpt%2][1]?>"><input type="radio" NAME="<?=$varname.'type'?>" value="1" <?if((!isset(${$varname.'type'}))||(${$varname.'type'}==1)){?>checked<?}?>>Exact</td>
-				<td class="bar-search" align="center" bgcolor="#<?=$colors[$cpt%2][1]?>"><input type="radio" NAME="<?=$varname.'type'?>" value="2" <?if(${$varname.'type'}==2){?>checked<?}?>>Begins with</td>
-				<td class="bar-search" align="center" bgcolor="#<?=$colors[$cpt%2][1]?>"><input type="radio" NAME="<?=$varname.'type'?>" value="3" <?if(${$varname.'type'}==3){?>checked<?}?>>Contains</td>
-				<td class="bar-search" align="center" bgcolor="#<?=$colors[$cpt%2][1]?>"><input type="radio" NAME="<?=$varname.'type'?>" value="4" <?if(${$varname.'type'}==4){?>checked<?}?>>Ends with</td>
+				<td class="bar-search" align="left" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
+				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr><td>&nbsp;&nbsp;<INPUT TYPE="text" NAME="<?php echo $varname?>" value="<?php echo $$varname?>"></td>
+				<td class="bar-search" align="center" bgcolor="#<?php echo $colors[$cpt%2][1]?>"><input type="radio" NAME="<?php echo $varname.'type'?>" value="1" <?php if((!isset(${$varname.'type'}))||(${$varname.'type'}==1)){?>checked<?php }?>>Exact</td>
+				<td class="bar-search" align="center" bgcolor="#<?php echo $colors[$cpt%2][1]?>"><input type="radio" NAME="<?php echo $varname.'type'?>" value="2" <?php if(${$varname.'type'}==2){?>checked<?php }?>>Begins with</td>
+				<td class="bar-search" align="center" bgcolor="#<?php echo $colors[$cpt%2][1]?>"><input type="radio" NAME="<?php echo $varname.'type'?>" value="3" <?php if(${$varname.'type'}==3){?>checked<?php }?>>Contains</td>
+				<td class="bar-search" align="center" bgcolor="#<?php echo $colors[$cpt%2][1]?>"><input type="radio" NAME="<?php echo $varname.'type'?>" value="4" <?php if(${$varname.'type'}==4){?>checked<?php }?>>Ends with</td>
 				</tr></table></td>
 			</tr>			
-	<?
+	<?php
 } 
 $cpt++;
 ?>
-     <td class="bar-search" align="left" bgcolor="#<?=$colors[$cpt%2][0]?>"> </td>
-				<td class="bar-search" align="center" bgcolor="#<?=$colors[$cpt%2][1]?>">
+     <td class="bar-search" align="left" bgcolor="#<?php echo $colors[$cpt%2][0]?>"> </td>
+				<td class="bar-search" align="center" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
 
 					<input type="image"  name="image16" align="top" border="0" src="images/button-search.gif" />
 					&nbsp;&nbsp;&nbsp;&nbsp;
-					Result : Minutes<input type="radio" NAME="resulttype" value="min" <?if((!isset($resulttype))||($resulttype=="min")){?>checked<?}?>> - Seconds <input type="radio" NAME="resulttype" value="sec" <?if($resulttype=="sec"){?>checked<?}?>>
+					Result : Minutes<input type="radio" NAME="resulttype" value="min" <?php if((!isset($resulttype))||($resulttype=="min")){?>checked<?php }?>> - Seconds <input type="radio" NAME="resulttype" value="sec" <?php if($resulttype=="sec"){?>checked<?php }?>>
 	  			</td>
     		</tr>
 		</tbody></table>
@@ -522,21 +520,57 @@ $cpt++;
 </center>
 <br>
 
-<?
+<?php
   if(defined('LOGUSERHTML') )
     echo LOGUSERHTML;
 ?>
 
+<!-- ** ** ** ** ** Player is not visible by default ** ** ** ** ** -->
+<script type="text/javascript" src="player/swfobject.js"></script>
+<div id="justforhide" style="visibility:hidden;text-align:center;">
+  <div id="dewplayer_content">
+    <object data="player/dewplayer.swf" width="200" height="20" 
+      name="dewplayer" id="dewplayer" type="application/x-shockwave-flash">
+    <param name="movie" value="dewplayer.swf" />
+    </object>
+  </div>
+</div>
+<script type="text/javascript">
+function play() {
+  var dewp = document.getElementById("dewplayer");
+  if(dewp!=null) dewp.dewplay();
+}
+function set(file) {
+  var dewp = document.getElementById("dewplayer");
+  if(dewp!=null) {
+    document.getElementById("justforhide").style.visibility="visible";
+	  dewp.dewset(file);
+  }
+}
+
+var flashvars = {
+  mp3: "",
+  javascript: "on"
+};
+var params = {
+  wmode: "transparent"
+};
+var attributes = {
+  id: "dewplayer"
+};
+swfobject.embedSWF("player/dewplayer.swf", "dewplayer_content", "200", "20", "9.0.0", false, flashvars, params, attributes);
+</script>
+
 <!-- ** ** ** ** ** Part to display the CDR ** ** ** ** ** -->
 
-			<center>Number of calls : <? if (is_array($list) && count($list)>0){ echo $nb_record; }else{echo "0";}?></center>
-      <table width="<?=$FG_HTML_TABLE_WIDTH?>" border="0" align="center" cellpadding="0" cellspacing="0">
+			<center>Number of calls : <?php if (is_array($list) && count($list)>0){ echo $nb_record; }else{echo "0";}?></center>
+      <table width="<?php echo $FG_HTML_TABLE_WIDTH?>" border="0" align="center" cellpadding="0" cellspacing="0">
 <TR bgcolor="#ffffff"> 
           <TD bgColor=#7f99cc height=16 style="PADDING-LEFT: 5px; PADDING-RIGHT: 3px"> 
             <TABLE border=0 cellPadding=0 cellSpacing=0 width="100%">
               <TBODY>
                 <TR> 
-                  <TD><SPAN style="COLOR: #ffffff; FONT-SIZE: 11px"><B><?=$FG_HTML_TABLE_TITLE?></B></SPAN></TD>
+                  <TD><SPAN style="COLOR: #ffffff; FONT-SIZE: 11px"><B><?php echo $FG_HTML_TABLE_TITLE?></B></SPAN></TD>
                   <TD align=right> <IMG alt="Back to Top" border=0 height=12 src="images/btn_top_12x12.gif" width=12> 
                   </TD>
                 </TR>
@@ -547,7 +581,7 @@ $cpt++;
           <TD> <TABLE border=0 cellPadding=0 cellSpacing=0 width="100%">
 <TBODY>
                 <TR bgColor=#F0F0F0> 
-				  <TD width="<?=$FG_ACTION_SIZE_COLUMN?>" align=center class="tableBodyRight" style="PADDING-BOTTOM: 2px; PADDING-LEFT: 2px; PADDING-RIGHT: 2px; PADDING-TOP: 2px"></TD>					
+				  <TD width="<?php echo $FG_ACTION_SIZE_COLUMN?>" align=center class="tableBodyRight" style="PADDING-BOTTOM: 2px; PADDING-LEFT: 2px; PADDING-RIGHT: 2px; PADDING-TOP: 2px"></TD>					
 				  
                   <?php 
 				  	if (is_array($list) && count($list)>0){
@@ -558,29 +592,29 @@ $cpt++;
 					?>				
 				  
 					
-                  <TD width="<?=$FG_TABLE_COL[$i][2]?>" align=middle class="tableBody" style="PADDING-BOTTOM: 2px; PADDING-LEFT: 2px; PADDING-RIGHT: 2px; PADDING-TOP: 2px"> 
+                  <TD width="<?php echo $FG_TABLE_COL[$i][2]?>" align=middle class="tableBody" style="PADDING-BOTTOM: 2px; PADDING-LEFT: 2px; PADDING-RIGHT: 2px; PADDING-TOP: 2px"> 
                     <center><strong> 
-                    <? if (strtoupper($FG_TABLE_COL[$i][4])=="SORT"){?>
-                    <a href="?<? echo "&current_page=$current_page&order=".$FG_TABLE_COL[$i][1]."&sens=";
+                    <?php if (strtoupper($FG_TABLE_COL[$i][4])=="SORT"){?>
+                    <a href="?<?php echo "&current_page=$current_page&order=".$FG_TABLE_COL[$i][1]."&sens=";
                     echo $sens=="ASC"?"DESC":"ASC"; 
 					          echo getmegaurl();?>">
 
-                    <span class="liens"><? } ?>
-                    <?=$FG_TABLE_COL[$i][0]?> 
-                    <?if ($order==$FG_TABLE_COL[$i][1] && $sens=="ASC"){?>
+                    <span class="liens"><?php } ?>
+                    <?php echo $FG_TABLE_COL[$i][0]?> 
+                    <?php if ($order==$FG_TABLE_COL[$i][1] && $sens=="ASC"){?>
                     &nbsp;<img src="images/icon_up_12x12.GIF" width="12" height="12" border="0"> 
-                    <?}elseif ($order==$FG_TABLE_COL[$i][1] && $sens=="DESC"){?>
+                    <?php }elseif ($order==$FG_TABLE_COL[$i][1] && $sens=="DESC"){?>
                     &nbsp;<img src="images/icon_down_12x12.GIF" width="12" height="12" border="0"> 
-                    <?}?>
-                    <? if (strtoupper($FG_TABLE_COL[$i][4])=="SORT"){?>
+                    <?php }?>
+                    <?php if (strtoupper($FG_TABLE_COL[$i][4])=="SORT"){?>
                     </span></a> 
-                    <?}?>
+                    <?php }?>
                     </strong></center></TD>
 				   <?php } ?>		
 				  	
                 </TR>
                 <TR> 
-                  <TD bgColor=#e1e1e1 colSpan=<?=$FG_TOTAL_TABLE_COL?> height=1><IMG 
+                  <TD bgColor=#e1e1e1 colSpan=<?php echo $FG_TOTAL_TABLE_COL?> height=1><IMG 
                               height=1 
                               src="images/clear.gif" 
                               width=1></TD>
@@ -595,13 +629,13 @@ $cpt++;
 						 $ligne_number++;
 				?>
 				
-               		 <TR bgcolor="<?=$FG_TABLE_ALTERNATE_ROW_COLOR[$ligne_number%2]?>"  onMouseOver="bgColor='#C4FFD7'" onMouseOut="bgColor='<?=$FG_TABLE_ALTERNATE_ROW_COLOR[$ligne_number%2]?>'"> 
-						<TD vAlign=top align="<?=$FG_TABLE_COL[$i][3]?>" class=tableBody><? echo $ligne_number+$current_page*$FG_LIMITE_DISPLAY.".&nbsp;"; ?></TD>
+               		 <TR bgcolor="<?php echo $FG_TABLE_ALTERNATE_ROW_COLOR[$ligne_number%2]?>"  onMouseOver="bgColor='#C4FFD7'" onMouseOut="bgColor='<?php echo $FG_TABLE_ALTERNATE_ROW_COLOR[$ligne_number%2]?>'"> 
+						<TD vAlign=top align="<?php echo $FG_TABLE_COL[$i][3]?>" class=tableBody><?php echo $ligne_number+$current_page*$FG_LIMITE_DISPLAY.".&nbsp;"; ?></TD>
 							 
 				  		<?php for($i=0;$i<$FG_NB_TABLE_COL;$i++){ ?>
 						
 						  
-						<?	//$FG_TABLE_COL[$i][1];			
+						<?php	//$FG_TABLE_COL[$i][1];			
 							//$FG_TABLE_COL[]=array ("Name", "name", "20%");
 							
 							
@@ -637,14 +671,14 @@ $cpt++;
 							
 							
 				 		 ?>
-                 		 <TD vAlign=top align="<?=$FG_TABLE_COL[$i][3]?>" class=tableBody><?
+                 		 <TD vAlign=top align="<?php echo $FG_TABLE_COL[$i][3]?>" class=tableBody><?php
 						 if (isset ($FG_TABLE_COL[$i][11]) && strlen($FG_TABLE_COL[$i][11])>1){
 						 		call_user_func($FG_TABLE_COL[$i][11], $record_display);
 						 }else{
 						 		echo stripslashes($record_display);
 						 }						 
 						 ?></TD>
-				 		 <? } ?>
+				 		 <?php } ?>
                   
 					</TR>
 				<?php
@@ -652,13 +686,13 @@ $cpt++;
 					 while ($ligne_number < $FG_LIMITE_DISPLAY){
 					 	$ligne_number++;
 				?>
-					<TR bgcolor="<?=$FG_TABLE_ALTERNATE_ROW_COLOR[$ligne_number%2]?>"> 
+					<TR bgcolor="<?php echo $FG_TABLE_ALTERNATE_ROW_COLOR[$ligne_number%2]?>"> 
 				  		<?php for($i=0;$i<$FG_NB_TABLE_COL;$i++){ 
 							//$FG_TABLE_COL[$i][1];			
 							//$FG_TABLE_COL[]=array ("Name", "name", "20%");
 				 		 ?>
                  		 <TD vAlign=top class=tableBody>&nbsp;</TD>
-				 		 <? } ?>
+				 		 <?php } ?>
                  		 <TD align="center" vAlign=top class=tableBodyRight>&nbsp;</TD>				
 					</TR>
 									
@@ -670,12 +704,12 @@ $cpt++;
 				  }//end_if
 				 ?>
                 <TR> 
-                  <TD class=tableDivider colSpan=<?=$FG_TOTAL_TABLE_COL?>><IMG height=1 
+                  <TD class=tableDivider colSpan=<?php echo $FG_TOTAL_TABLE_COL?>><IMG height=1 
                               src="images/clear.gif" 
                               width=1></TD>
                 </TR>
                 <TR> 
-                  <TD class=tableDivider colSpan=<?=$FG_TOTAL_TABLE_COL?>><IMG height=1 
+                  <TD class=tableDivider colSpan=<?php echo $FG_TOTAL_TABLE_COL?>><IMG height=1 
                               src="images/clear.gif" 
                               width=1></TD>
                 </TR>
@@ -688,19 +722,19 @@ $cpt++;
               <TBODY>
                 <TR> 
                   <TD align="right"><SPAN style="COLOR: #ffffff; FONT-SIZE: 11px"><B> 
-                    <?if ($current_page>0){?>
+                    <?php if ($current_page>0){?>
                     <img src="images/fleche-g.gif" width="5" height="10">
-          <a href="?&order=<?=$order?>&sens=<?=$sens?>&current_page=<? echo ($current_page-1)?><? if (!is_null($letter) && ($letter!="")){ echo "&letter=$letter";} 
+          <a href="?&order=<?php echo $order?>&sens=<?php echo $sens?>&current_page=<?php echo ($current_page-1)?><?php if (!is_null($letter) && ($letter!="")){ echo "&letter=$letter";} 
 					echo getmegaurl();?>">
                     Previous </a> - 
-                    <?}?>
-                    <?echo ($current_page+1);?> / <? echo $nb_record_max;?> 
-                    <?if ($current_page<$nb_record_max-1){?>
-                    - <a href="?&order=<?=$order?>&sens=<?=$sens?>&current_page=<? echo ($current_page+1)?><? if (!is_null($letter) && ($letter!="")){ echo "&letter=$letter";}
+                    <?php }?>
+                    <?php echo ($current_page+1);?> / <?php echo $nb_record_max;?> 
+                    <?php if ($current_page<$nb_record_max-1){?>
+                    - <a href="?&order=<?php echo $order?>&sens=<?php echo $sens?>&current_page=<?php echo ($current_page+1)?><?php if (!is_null($letter) && ($letter!="")){ echo "&letter=$letter";}
 					echo getmegaurl();?>">
                     Next </a> <img src="images/fleche-d.gif" width="5" height="10"> 
                     </B></SPAN> 
-                    <?}?>
+                    <?php }?>
                   </TD>
               </TBODY>
             </TABLE></TD>
@@ -710,7 +744,7 @@ $cpt++;
 <!-- ** ** ** ** ** Part to display the GRAPHIC ** ** ** ** ** -->
 <br><br>
 
-<?
+<?php
 
 if (is_array($list_total_day) && count($list_total_day)>0){
 /*if (is_array($list) && count($list)>0){
@@ -781,7 +815,7 @@ foreach ($list_total_day as $data){
 		<td align="center"><font face="verdana" size="1" color="#ffffff"><b> <acronym title="Average Connection Time">ACT</acronym> </b></font></td>
                 			
 		<!-- LOOP -->
-	<? 		
+	<?php 		
 		$i=0;
 		// #ffffff #cccccc
 		foreach ($list_total_day as $data){	
@@ -805,15 +839,15 @@ foreach ($list_total_day as $data){
 		//bgcolor="#336699" 
 	?>
 		</tr><tr>
-		<td align="right" class="sidenav" nowrap="nowrap"><font face="verdana" size="1" color="#ffffff"><?=$data[0]?></font></td>
-		<td bgcolor="<?=$FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="right" nowrap="nowrap"><font face="verdana" color="#000000" size="1"><?=$minutes?> </font></td>
-        <td bgcolor="<?=$FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="left" nowrap="nowrap" width="<?=$widthbar+60?>">
+		<td align="right" class="sidenav" nowrap="nowrap"><font face="verdana" size="1" color="#ffffff"><?php echo $data[0]?></font></td>
+		<td bgcolor="<?php echo $FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="right" nowrap="nowrap"><font face="verdana" color="#000000" size="1"><?php echo $minutes?> </font></td>
+        <td bgcolor="<?php echo $FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="left" nowrap="nowrap" width="<?php echo $widthbar+60?>">
         <table cellspacing="0" cellpadding="0"><tbody><tr>
-        <td bgcolor="#e22424"><img src="images/spacer.gif" width="<?=$widthbar?>" height="6"></td>
+        <td bgcolor="#e22424"><img src="images/spacer.gif" width="<?php echo $widthbar?>" height="6"></td>
         </tr></tbody></table></td>
-        <td bgcolor="<?=$FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="right" nowrap="nowrap"><font face="verdana" color="#000000" size="1"><?=$data[2]?></font></td>
-        <td bgcolor="<?=$FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="right" nowrap="nowrap"><font face="verdana" color="#000000" size="1"><?=$tmc?> </font></td>
-     <?	 }	 	 	
+        <td bgcolor="<?php echo $FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="right" nowrap="nowrap"><font face="verdana" color="#000000" size="1"><?php echo $data[2]?></font></td>
+        <td bgcolor="<?php echo $FG_TABLE_ALTERNATE_ROW_COLOR[$i]?>" align="right" nowrap="nowrap"><font face="verdana" color="#000000" size="1"><?php echo $tmc?> </font></td>
+     <?php	 }	 	 	
 	 	
 		if ((!isset($resulttype)) || ($resulttype=="min")){  
 			$total_tmc = sprintf("%02d",intval(($totalminutes/$totalcall)/60)).":".sprintf("%02d",intval(($totalminutes/$totalcall)%60));				
@@ -832,9 +866,9 @@ foreach ($list_total_day as $data){
 	<!-- TOTAL -->
 	<tr bgcolor="#600101">
 		<td align="right" nowrap="nowrap"><font face="verdana" size="1" color="#ffffff"><b>TOTAL</b></font></td>
-		<td align="center" nowrap="nowrap" colspan="2"><font face="verdana" size="1" color="#ffffff"><b><?=$totalminutes?> </b></font></td>
-		<td align="center" nowrap="nowrap"><font face="verdana" size="1" color="#ffffff"><b><?=$totalcall?></b></font></td>
-		<td align="center" nowrap="nowrap"><font face="verdana" size="1" color="#ffffff"><b><?=$total_tmc?></b></font></td>                        
+		<td align="center" nowrap="nowrap" colspan="2"><font face="verdana" size="1" color="#ffffff"><b><?php echo $totalminutes?> </b></font></td>
+		<td align="center" nowrap="nowrap"><font face="verdana" size="1" color="#ffffff"><b><?php echo $totalcall?></b></font></td>
+		<td align="center" nowrap="nowrap"><font face="verdana" size="1" color="#ffffff"><b><?php echo $total_tmc?></b></font></td>                        
 	</tr>
 	<!-- FIN TOTAL -->
 
@@ -852,7 +886,7 @@ foreach ($list_total_day as $data){
 </td></tr></table>
 
 
-<? }else{ ?>
+<?php }else{ ?>
 	<center><h3>No calls in your selection.</h3></center>
-<? } ?>
+<?php } ?>
 </center>
