@@ -1,4 +1,4 @@
-<?
+<?php
 require_once(dirname(__FILE__) . "/lib/defines.php");
 
 getpost_ifset(array('s'));
@@ -19,6 +19,7 @@ $array = array (
 if (  USER_CAN_CHPASS != 0 || $_SESSION['admin'] == 1 )  $array[4]="User Settings";
 if ( $_SESSION['admin'] == 1  )  $array[14]="Users List";
 if ( $_SESSION['admin'] == 1  )  $array[16]="User Create";
+$array[10] = "Logs Filter";
 if ( PURGE != 0 && $_SESSION['admin'] == 1  )  $array[5]="Purge History";
 $array[9]=$_SESSION["username"]." Logout";
 
@@ -41,7 +42,7 @@ $array[9]=$_SESSION["username"]." Logout";
 		<!-- header BEGIN -->
 		<div id="fedora-header">
 			<div id="fedora-header-logo">
-				 <table cellpadding="0" cellspacing="0"><tr><td><img src="<?=LOGOFILE?>"  alt="CDR (Call Detail Records)"></td>
+				 <table cellpadding="0" cellspacing="0"><tr><td><img src="<?php echo LOGOFILE?>"  alt="CDR (Call Detail Records)"></td>
       </tr></table>
 			</div>  	
     </div>		
@@ -50,7 +51,7 @@ $array[9]=$_SESSION["username"]." Logout";
 		<!-- leftside BEGIN -->
 		<div id="fedora-side-left">       
       <ul id="fedora-side-nav">
-      <? 
+      <?php 
       foreach ($array as $key => $value) {
         $op_strong = ($key==$s) ? '<strong>' : '';
         $cl_strong = ($key==$s) ? '</strong>' : '';
@@ -70,7 +71,7 @@ $array[9]=$_SESSION["username"]." Logout";
 
 
 
-<?
+<?php
 switch($s){
   case 0:
     require_once("call-log.php");break;
@@ -86,22 +87,44 @@ switch($s){
     require_once("call-purge.php");break;
 //  case 9: //done at begin
 //  header("location: ?action=logOut");exit;
+  case 10:
+	require_once("logfilter.php");break;
   case 14:
     require_once("listusers.php");break;
   case 16:
     require_once("newuser.php");break;
+  case 21:
+	require_once("staticAll.php");break;
+  case 22:
+	require_once("staticRecognizeMSGErr.php");break;
+  case 23:
+	require_once("staticMSGErr.php");break;
+  case 24:
+	require_once("staticCustom.php");break;
+  case 29:
+	require_once("staticErrors.php");break;
+  case 31:
+	require_once("dynamicAll.php");break;
+  case 32:
+	require_once("dynamicRecognizeMSGErr.php");break;
+  case 33:
+	require_once("dynamicMSGErr.php");break;
+  case 34:
+	require_once("dynamicCustom.php");break;
+  case 39:
+	require_once("dynamicErrors.php");break;
   default:
   ?>
 		<h1>About</h1> 		
 	  <table width="90%">
 	  <tr> 
   	  <td>
-      <?=ABOUT?>
+      <?php echo ABOUT?>
       </td>
     </tr>    
 	  </table>
-  <br><br><em><strong>Last update:</strong></em> <?=strtr($update,array(': '=>'', '$'=>''))?><br>
-  <?
+  <br><br><em><strong>Last update:</strong></em> <?php echo strtr($update,array(': '=>'', '$'=>''))?><br>
+  <?php
 
 
 }?>
