@@ -4,7 +4,7 @@ define ("DB_TYPE", "mysql"); // mysql or postgres
 require_once(dirname(__FILE__)."/DB-modules/phplib_".DB_TYPE.".php");
 
 //CVS Date
-$update ="$Date: 2011-03-23 18:25:02 $";
+$update ="$Date: 2013-05-28 09:37:16 $";
 
 //Mysql settings
 define ("DBHOST", "localhost");
@@ -33,14 +33,7 @@ $_VCHAR_SEARCH=array(
   "accountcode" => "ACCOUNTCODE",
 );
 
-//operator search 
-/*
-$_VCHAR_SEARCH_operator=array(
-  "dst"         => "DESTINATION",
-  "src"         => "SOURCE",
-  "clid"        => "CLI",
-);
- */
+
 
 //admin =  array(Fecha, Hora, Origen, Destino, Duración, Código Cliente, Código Empleado, Audio, Lastapp, Acción)
 //Default
@@ -54,11 +47,24 @@ $_FG_TABLE_COL=array(
         array ("Destino", "dst", "12%", "center", "SORT", "30"),
         array ("APP", "dst", "1%", "center", "", "30","list", $appli_list),
         array ("Accion", "disposition", "9%", "center", "SORT", "30"),
-        array ("Dur.", "duration", "10%", "center", "SORT", "30", "", "", "", "", "", "$minute_function"),
+      	array ("Dur.", "duration", "10%", "center", "SORT", "30", "", "", "", "", "", "$minute_function"),
+      //Uncomment line above for record column
+      //array ("Record", "uniqueid", "4%", "center", "", "100", "", "", "", "", "", "display_play"),
         array ("UserField", "userfield", "4%", "center", "", "100", "", "", "", "", "", ""),
         array ("Accountcode", "accountcode", "8%", "center", "", "20"),
 );
 /*
+
+//by user specific search 
+//operator search 
+
+$_VCHAR_SEARCH_operator=array(
+  "dst"         => "DESTINATION",
+  "src"         => "SOURCE",
+  "clid"        => "CLI",
+);
+
+
 //lector = array(Fecha, Hora, Origen, Destino, Duración, Lastapp, Acción)
 $_FG_TABLE_COL_operator=array(
         array ("Date", "calldate", "15%", "center", "SORT", "19"),
@@ -71,64 +77,11 @@ $_FG_TABLE_COL_operator=array(
         array ("Accion", "disposition", "9%", "center", "", "30"),
         array ("Dur.", "duration", "10%", "center", "SORT", "30", "", "", "", "", "", "$minute_function"),
 );
+*/
 
-$_FG_TABLE_COL_recobro=array(
-        array ("Date", "calldate", "15%", "center", "SORT", "19"),
-      //array ("Channel", "channel", "20%", "center", "", "30", "", "", "", "", "", "display_acronym"),
-        array ("Source", "src", "5%", "center", "", "30"),
-        array ("Clid", "clid", "5%", "center", "", "30"),
-        array ("Lastapp", "lastapp", "8%", "center", "", "30"),
-      //array ("Lastdata", "lastdata", "5%", "center", "", "30"),
-        array ("Destino", "dst", "12%", "center", "SORT", "30"),
-        array ("Accion", "disposition", "9%", "center", "", "30"),
-        array ("Dur.", "duration", "10%", "center", "SORT", "30", "", "", "", "", "", "$minute_function"),
-        array ("Audio", "userfield", "4%", "center", "", "100", "", "", "", "", "", "display_link"),
-        array ("Mp3", "userfield", "15%", "center", "", "100", "", "", "", "", "", "display_mp3"),
-);
- */
-
-/*
-//Player
-define ("LOGUSERHTML",
-'
-<script type="text/javascript" src="extra/swfobject.js"></script>
-<div id="justforhide" style="visibility:hidden;text-align:center;">
-  <div id="dewplayer_content">
-    <object data="extra/dewplayer.swf" width="200" height="20" 
-      name="dewplayer" id="dewplayer" type="application/x-shockwave-flash">
-    <param name="movie" value="dewplayer.swf" />
-    </object>
-  </div>
-</div>
-<script type="text/javascript">
-function play() {
-  var dewp = document.getElementById("dewplayer");
-  if(dewp!=null) dewp.dewplay();
-}
-function set(file) {
-  var dewp = document.getElementById("dewplayer");
-  if(dewp!=null) {
-    document.getElementById("justforhide").style.visibility="visible";
-	  dewp.dewset(file);
-  }
-}
-
-var flashvars = {
-  mp3: "",
-  javascript: "on"
-};
-var params = {
-  wmode: "transparent"
-};
-var attributes = {
-  id: "dewplayer"
-};
-swfobject.embedSWF("extra/dewplayer.swf", "dewplayer_content", "200", "20", "9.0.0", false, flashvars, params, attributes);
-</script>
-
-'
-);
- */
+//Specific HTML
+//define ("LOGUSERHTML",'Any HTML');
+ 
 
 define ("ABOUT",
 '<h3><a href="http://www.i6net.com">I6net Solutions and technologies</a><br><br>
@@ -216,15 +169,14 @@ function display_acronym($field){
 		echo '<acronym title="'.$field.'">'.substr($field,0,35).'...</acronym>';		
 }
 
-function display_link($field){
-		echo '<a  href="javascript:set(\'extra/'.basename($field).'\');" ><img src="extra/play.png" border="0" title="'.basename($field).'"></img></a>';
+function display_play($uniqueid){
+	$found=glob("/var/spool/asterisk/monitor/${uniqueid}-*.wav");
+	if(count($found)>0){
+
+		echo '<a  href="javascript:set(\'play.php?file='.urlencode(basename($found[0])).'\');" ><img src="images/play.png" border="0" title="'.basename($field).'"></img></a>&nbsp;';
+		echo '<a  href="play.php?file='.urlencode(basename($found[0])).'"><img src="images/down.png" border="0" title="'.basename($field).'"></img></a>';
+	}
 }
 
-function display_mp3($field){
-		echo '<a  href="'.$field.'">'.basename($field).'</a>';
-}
-
-
-
 
 ?>
